Module: JekyllFrontAdder
- Defined in:
- lib/jekyll-frontadder.rb,
lib/jekyll_frontadder/version.rb
Overview
This plugin adds up build hours from each build log entry and pushes a running total on each post
V1 only handles hour summary
TODO: Extend to process multiple types of efforts
Defined Under Namespace
Classes: JekyllFrontAdderGen
Constant Summary collapse
- VERSION =
'0.0.1'